==> react-molecule-tabs-2.27.0.tgz: package/lib/components/MoleculeTabs.js <==
import { Children, cloneElement, isValidElement } from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
import { BASE_CLASS, CLASS_CONTENT, CLASS_SCROLLER, TYPES, VARIANTS } from '../config';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

var MoleculeTabs = function MoleculeTabs(_ref) {
  var variant = _ref.variant,
      type = _ref.type,
      children = _ref.children,
      onChange = _ref.onChange;
  var CLASS_VARIANT = BASE_CLASS + "--" + variant;
  var CLASS_TYPE = BASE_CLASS + "--" + type;
  var className = cx(BASE_CLASS, CLASS_VARIANT, CLASS_TYPE);
  var childrenArray = Children.toArray(children);
  var extendedChildren = childrenArray.filter(function (child) {
    return /*#__PURE__*/isValidElement(child);
  }).map(function (child, index) {
    var numTab = index + 1;
    return /*#__PURE__*/cloneElement(child, {
      onChange: onChange,
      numTab: numTab
    });
  });
  var activeTabContent = childrenArray.reduce(function (activeContent, child) {
    if (child) {
      var _child$props = child.props,
          childrenChild = _child$props.children,
          active = _child$props.active;
      return active ? childrenChild : activeContent;
    }
  }, null);
  return /*#__PURE__*/_jsxs("div", {
    className: className,
    children: [/*#__PURE__*/_jsx("ul", {
      className: CLASS_SCROLLER,
      children: extendedChildren
    }), activeTabContent ? /*#__PURE__*/_jsx("div", {
      className: CLASS_CONTENT,
      children: activeTabContent
    }) : null]
  });
};

MoleculeTabs.displayName = 'MoleculeTabs';
MoleculeTabs.defaultProps = {
  variant: VARIANTS.CLASSIC,
  type: TYPES.HORIZONTAL,
  onChange: function onChange() {}
};
export default MoleculeTabs;

==> react-molecule-tabs-2.29.0.tgz: package/lib/components/MoleculeTabs.js <==
import { Children, cloneElement, isValidElement } from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
import useOnScreen from '@s-ui/react-hooks/lib/useOnScreen';
import { BASE_CLASS, CLASS_CONTENT, CLASS_SCROLLER, TYPES, VARIANTS } from '../config';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

var MoleculeTabs = function MoleculeTabs(_ref) {
  var _cx;

  var variant = _ref.variant,
      type = _ref.type,
      children = _ref.children,
      onChange = _ref.onChange;
  var className = cx(BASE_CLASS, (_cx = {}, _cx[BASE_CLASS + "--" + variant] = variant, _cx[BASE_CLASS + "--" + type] = type, _cx));
  var childrenArray = Children.toArray(children);

  var _useOnScreen = useOnScreen(),
      isIntersecting = _useOnScreen[0],
      outerRef = _useOnScreen[1];

  var extendedChildren = childrenArray.filter(function (child) {
    return /*#__PURE__*/isValidElement(child);
  }).map(function (child, index) {
    var numTab = index + 1;
    return /*#__PURE__*/cloneElement(child, {
      onChange: onChange,
      numTab: numTab,
      isIntersecting: isIntersecting
    });
  });
  var activeTabContent = childrenArray.reduce(function (activeContent, child) {
    if (child) {
      var _child$props = child.props,
          childrenChild = _child$props.children,
          active = _child$props.active;
      return active ? childrenChild : activeContent;
    }
  }, null);
  return /*#__PURE__*/_jsxs("div", {
    className: className,
    children: [/*#__PURE__*/_jsx("ul", {
      ref: outerRef,
      className: CLASS_SCROLLER,
      children: extendedChildren
    }), activeTabContent ? /*#__PURE__*/_jsx("div", {
      className: CLASS_CONTENT,
      children: activeTabContent
    }) : null]
  });
};

MoleculeTabs.displayName = 'MoleculeTabs';
MoleculeTabs.defaultProps = {
  variant: VARIANTS.CLASSIC,
  type: TYPES.HORIZONTAL,
  onChange: function onChange() {}
};
export default MoleculeTabs;
